pub enum Selector {
Height(BlockHeight),
Hash(Hash),
Latest(bool),
Finalized(bool),
}Variants
Height(BlockHeight)
Hash(Hash)
Latest(bool)
selector == “latest” shorthand
Finalized(bool)
selector == “finalized” (BFT-finalized head)
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn merge(
field: &mut Option<Selector>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Selector>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.