pub struct MempoolEntry {
pub txid: Option<Hash>,
pub from_address: Option<Address>,
pub to_address: Option<Address>,
pub amount: Option<Amount>,
pub fee: Option<Amount>,
pub nonce: u64,
pub tx_type: u32,
}Fields
txid: Option<Hash>from_address: Option<Address>to_address: Option<Address>amount: Option<Amount>fee: Option<Amount>nonce: u64tx_type: u32Trait Implementations
Sourceimpl Clone for MempoolEntry
impl Clone for MempoolEntry
Sourcefn clone(&self) -> MempoolEntry
fn clone(&self) -> MempoolEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MempoolEntry
impl Debug for MempoolEntry
Sourceimpl Default for MempoolEntry
impl Default for MempoolEntry
Sourceimpl Hash for MempoolEntry
impl Hash for MempoolEntry
Sourceimpl Message for MempoolEntry
impl Message for MempoolEntry
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MempoolEntry
impl PartialEq for MempoolEntry
Sourcefn eq(&self, other: &MempoolEntry) -> bool
fn eq(&self, other: &MempoolEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MempoolEntry
impl StructuralPartialEq for MempoolEntry